==> ovretl-2.0.0-py3-none-any.whl: ovretl/loads_utils/tests/test_merge_with_propositions_loads_then_with_shipments_loads.py <==
import pandas as pd
import numpy as np
from pandas.util.testing import assert_frame_equal


from ovretl.loads_utils.merge_shipments_with_loads import (
    split_propositions_shipments_loads,
    merge_with_propositions_loads_then_with_shipments_loads,
)


def test_merge_with_propositions_loads_then_with_shipments_loads():
    loads_df = pd.DataFrame(
        data={
            "total_weight": [200, 100, 200, 200],
            "total_volume": [0.9, 0.9, 1, 0.96],
            "shipment_id": [np.nan, np.nan, "2", "3"],
            "proposition_id": ["0", "1", np.nan, np.nan],
            "taxable_weight": [200, 150, 200, 200],
            "weight_measurable": [1, 1, 1, 1],
        }
    )
    shipments_df = pd.DataFrame(data={"shipment_id": [np.nan, "2", "3"], "proposition_id": ["0", "1", np.nan]})
    shipments_df_true = pd.DataFrame(
        data={
            "shipment_id": [np.nan, "2", "3"],
            "proposition_id": ["0", "1", np.nan],
            "total_volume": [0.9, 0.9, 0.96],
            "total_weight": [200, 100, 200],
            "taxable_weight": [200, 150, 200],
            "weight_measurable": [1, 1, 1],
        }
    )
    (propositions_loads_df, shipments_loads_df,) = split_propositions_shipments_loads(loads_df)

    shipments_df_processed = merge_with_propositions_loads_then_with_shipments_loads(
        shipments_df=shipments_df, propositions_loads_df=propositions_loads_df, shipments_loads_df=shipments_loads_df,
    )
    assert_frame_equal(shipments_df_processed, shipments_df_true, check_dtype=False)

==> ovretl-4.6.7-py3-none-any.whl: ovretl/loads_utils/tests/test_merge_with_propositions_loads_then_with_shipments_loads.py <==
import numpy as np
import pandas as pd
from ovretl.loads_utils.merge_shipments_with_loads import (
    split_propositions_shipments_loads,
    merge_with_propositions_loads_then_with_shipments_loads,
)
from pandas.util.testing import assert_frame_equal

pd.set_option("display.max_columns", None)


def test_merge_with_propositions_loads_then_with_shipments_loads():
    loads_df = pd.DataFrame(
        data={
            "total_number": [1, 2, 1, 1],
            "total_weight": [200, 100, 200, 200],
            "total_volume": [0.9, 0.9, 1, 0.96],
            "shipment_id": [np.nan, np.nan, "2", "3"],
            "proposition_id": ["0", "1", np.nan, np.nan],
            "taxable_weight": [200, 150, 200, 200],
            "weight_measurable": [1, 1, 1, 1],
            "hazardous": [True, True, False, False],
            "non_stackable": [True, False, False, False],
            "magnetic": [False, False, False, False],
            "refrigerated": [False, False, False, False],
            "lithium": [False, False, False, False],
        }
    )
    shipments_df = pd.DataFrame(data={"shipment_id": [np.nan, "2", "3"], "proposition_id": ["0", "1", np.nan]})
    result_should_be = pd.DataFrame(
        data={
            "shipment_id": [np.nan, "2", "3"],
            "proposition_id": ["0", "1", np.nan],
            "total_number": [1, 2, 1],
            "total_volume": [0.9, 0.9, 0.96],
            "total_weight": [200, 100, 200],
            "taxable_weight": [200, 150, 200],
            "weight_measurable": [1, 1, 1],
            "loads_hazardous": [True, True, False],
            "non_stackable": [True, False, False],
            "loads_magnetic": [np.nan, np.nan, False],
            "loads_lithium": [np.nan, np.nan, False],
            "loads_refrigerated": [np.nan, np.nan, False],
        }
    )
    (propositions_loads_df, shipments_loads_df,) = split_propositions_shipments_loads(loads_df)

    result = merge_with_propositions_loads_then_with_shipments_loads(
        shipments_df=shipments_df, propositions_loads_df=propositions_loads_df, shipments_loads_df=shipments_loads_df,
    )
    assert_frame_equal(result, result_should_be, check_dtype=False)
